package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.GlobalFilesDTO;
import com.pjilisense.flxai.service.GlobalFilesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * ${comments}
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2025-02-10
 */
@RestController
@RequestMapping(Constant.BASE_PATH+"globalfiles")
@Api(tags="${comments}")
public class GlobalFilesController {

    private static Logger logger = LoggerFactory.getLogger(GlobalFilesController.class);

    @Autowired
    private GlobalFilesService globalFilesService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    public Result<PageData<GlobalFilesDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<GlobalFilesDTO> page = globalFilesService.page(params);

        return new Result<PageData<GlobalFilesDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<GlobalFilesDTO> get(@PathVariable("id") String id){
        GlobalFilesDTO data = globalFilesService.get(id);

        return new Result<GlobalFilesDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody GlobalFilesDTO dto){

        globalFilesService.save(dto);

        return new Result().ok(dto);
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody GlobalFilesDTO dto){

        globalFilesService.update(dto);

        return new Result().ok(dto);
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody String[] ids){

        globalFilesService.delete(ids);

        return new Result().ok(ids);
    }

}